@@ -18,4 +18,7 @@ def flider():
             file.close()
         except Exception as e:
             print(e)
-            print('Error on: ' + save_paths[i] + file_names[i])
\ No newline at end of file
+            print('Error on: ' + save_paths[i] + file_names[i])
+
+if __name__=='__main__':
+    flider()
\ No newline at end of file
